---
title: 네이버페이(결제형) 상세 계약절차
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 네이버페이(결제형) 상세 계약절차
  description: >-
    네이버페이(결제형) 가입을 위해서는 일반 PG 결제모듈이 연동하실 서비스에 이미 적용되어 있어야 하고, ‘최소 1개월이상’ 매출이
    발생되어야 심사 진행이 가능합니다.
  keywords:
    - 네이버페이(결제형)
    - 계약절차
tags:
  - 네이버페이(결제형)
  - 결제대행사 계약
pgCompanies:
  - 네이버페이(결제형)
searchTags:
  - 네이버페이결제형검수
  - 네이버페이검수
  - 네이버페이가입
  - 네이버페이계약
  - 네이버페이계약절차
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="네이버페이(결제형)와 계약을 맺으시기 위한 절차를 순서대로 알려드립니다." />

<Callout icon="💡" content="2021년 10월 15일부로, 네이버페이 내부 정책이 변경되어, 결제형 가입을 위해서는 **일반 PG 결제모듈이 연동하실 서비스에 이미 적용되어 있어야 하고, ‘최소 1개월이상’ 매출이 발생되어야 심사 진행이 가능한점** 참고 부탁 드립니다." title="참고사항" />

### 가입신청서 제출

[포트원 관리자콘솔↗](https://admin.portone.io/) 안에서 네이버페이(결제형)의 가입신청서를 제출합니다.

- 경로 : [포트원 관리자콘솔↗](https://admin.portone.io/) 회원가입 및 로그인 > 좌측 상단 \[전자결제 신청] 버튼 클릭 > 사업자등록증 업로드 > 네이버페이결제형 및 결제수단 선택 후 제출

<Callout icon="" title="전자결제 신청방법 보러가기↗" />





### **네이버페이 상점관리자페이지 내 접수**<Highlight text="(중요)" />

- 가입신청서 작성 완료하시면 포트원에서 담당자님 메일주소로 다음 절차를 안내드리고 있습니다.
- 네이버페이 안내메일을 확인하신 후 네이버페이 상점관리자페이지에서 추가 접수를 진행해주시기 바랍니다.\
  (자세한 사항은 전자결제 신청서 접수 이후 담당자님 메일로도 상세 안내드리고 있습니다)

### **계약진행**

- 네이버페이 1차 심사 기간은 서류 접수 완료일로부터 최대 1주일 소요되며,
- 메일을 통해 **1차 승인여부와 함께 테스트가 가능한 상점아이디**가 전달됩니다. 다음 절차인 검수과정을 준비해주세요.

### **검수진행**

- 홈페이지 내 상품정보 및 구매정보 연동여부를 확인하여 검수를 진행합니다. 아래의 세가지 단계를 순서대로 진행합니다.

#### 1. **채널 설정**

- 연동하실 네이버페이 상점정보를 설정합니다.

<Callout title="네이버페이(결제형) 채널설정방법 보러가기 ↗" icon="" />

#### 2. **개발 · 연동**

- 포트원에서 제공드리는 개발 연동 가이드를 참고하여 개발작업을 진행합니다.
- 사이트를 구축하고 계신 환경에 따라 본 과정의 진행방법이 상이하오니, 직접 사이트를 개발하신 경우는 <Tag text="자체개발" /> 가이드를, 워드프레스로 연동하시는 경우 <Tag text="워드프레스" /> 가이드를 참고하시기 바랍니다.
- <Tag text="자체개발" /> **[네이버페이(결제형)개발 가이드 ↗](https://developers.portone.io/opi/ko/integration/pg/v1/naver?v=v1)**
- <Tag text="워드프레스" /> **[네이버페이(결제형)설정 가이드 ↗](https://help.portone.io/content/wordpress-naverpay)**

#### 3 **. 검수요청**

사이트를 구축하고 계신 환경에 따라 본 과정의 진행방법이 상이하오니 직접 사이트를 개발하신 경우는 <Tag text="자체개발" /> 가이드를, 워드프레스로 연동하시는 경우 <Tag text="워드프레스" /> 가이드를 참고하여 검수를 요청해주시기 바랍니다.

<Callout icon="💡" content="1. 네이버페이는 다른 결제대행사와 다르게 사이트 검수 외에도 연동 및 구현하신 로직이 네이버페이의 정책과 맞는지 등에 대한 검수를 진행합니다.
2. 단순 필수정보 노출 뿐 아니라 여러 가지 UI · UX  및 기능 체크를 하게 됩니다.
3. 네이버페이 버튼이 네이버 내부의 디자인 가이드에 맞게 적용되어있는지 ,결제금액을 변조해서 결제를 해봤을 때 주문완료 처리를 하지 않고 걸러내는지,부분취소 기능은 잘 동작하는지 등등 을 전반적으로 사이트 검수하게 됩니다. 
**(네이버페이와 관련된 디자인 및 기능들을 점검하는데 통상적으로 2주 정도 소요됩니다)**" title="참고사항" />

<Tag text="자체개발" /> **[(참고)네이버페이(결제형)검수시 필요항목 ↗](https://help.portone.io/content/naverpay-review-items)**

<Tag text="워드프레스" /> **[(참고) 네이버페이(결제형)검수요청 방법 ↗](https://help.portone.io/content/wordpress-naverpay)**

### **검수완료**

- 연동상의 검수와 카드사 심사를 진행하며, 완료 시 서비스 오픈이 가능합니다.
- 단, 테스트용 사용하던 KEY와 실 운영환경에서 사용하실 상점 정보는 상이하니 (네이버페이의 경우 상점id만 동일하고 그 외의 정보는 상이합니다) 포트원 관리자콘솔안에서 채널정보를 변경하신 후 운영환경으로 오픈하여 주시기 바랍니다.
